@@ -1,8 +1,9 @@
-import typer
 import asyncio
-import requests
 import os
 
+import requests
+import typer
+
 llm = typer.Typer(short_help="The LLM management.")
 
 
@@ -50,6 +51,19 @@ def download_file_if_not_exists(url, save_path):
         print(f"File {save_path} already exists.")
 
 
+@llm.command(short_help="Collect the metrics of a running LLM server.")
+def collect(
+    duration: int = typer.Option(600, help="The duration of the collection."),
+):
+    from mw_python_sdk.llm.monitor import collect_with_duration
+    from mw_python_sdk import create_dataset
+    if not os.path.exists("./llm_benchmark"):
+        os.makedirs("./llm_benchmark")
+    if os.path.exists("./llm_benchmark/metrics.csv"):
+        os.remove("./llm_benchmark/metrics.csv")
+    collect_with_duration(duration, "./llm_benchmark/metrics.csv")
+    create_dataset("llm_benchmark", "./llm_benchmark", "", "llm benchmark metrics")
+
 @llm.command(short_help="Bench an online serving model.")
 def bench(
     base_url: str = typer.Option(
@@ -71,10 +85,11 @@ def bench(
 ):
     from mw_python_sdk.llm.bench import (
         benchmark,
-        set_ulimit,
-        get_tokenizer,
         get_dataset,
+        get_tokenizer,
+        set_ulimit,
     )
+    from mw_python_sdk.llm.plot import plot_metrics
 
     set_ulimit()
     api_url = f"{base_url}/v1/completions"
@@ -126,6 +141,18 @@ def bench(
             profile=False,
         )
     )
+    from mw_python_sdk import download_file, list_datasets
+
+    iter = list_datasets("llm_benchmark")
+    dataset = next(iter)
+    print("Downloading metrics.csv from dataset", dataset._id)
+    if os.path.exists("metrics.csv"):
+        os.remove("metrics.csv")
+    if os.path.exists("metrics.png"):
+        os.remove("metrics.png")
+    downloaded_file = download_file(dataset._id, "metrics.csv", local_dir="./")
+    plot_metrics(downloaded_file, "metrics.png")
+    print("Saved metrics plot as metrics.png")
 
 
 datasets = typer.Typer(short_help="The datasets management.")
@@ -159,9 +186,10 @@ def upload(
         False, "-r", help="Whether to recursively upload all files in the directory."
     ),
 ):
-    from mw_python_sdk import upload_file, upload_folder
     import os
 
+    from mw_python_sdk import upload_file, upload_folder
+
     if recursive:
         if not os.path.isdir(source):
             raise ValueError("Source must be a directory when using --recursive.")
@@ -187,7 +215,7 @@ def download(
         help="Whether to recursively download all files in the directory.",
     ),
 ):
-    from mw_python_sdk import download_file, download_dir
+    from mw_python_sdk import download_dir, download_file
 
     if recursive or source is None:
         downloaded_dir = download_dir(dataset, sub_dir=source, local_dir=destination)
